@@ -47,7 +47,7 @@ use Coro::AnyEvent ();
 
 use base Exporter::;
 
-our $VERSION = 6.42;
+our $VERSION = 6.49;
 our $WATCHER;
 
 BDB::set_sync_prepare {
@@ -64,10 +64,10 @@ BDB::set_sync_prepare {
 
 L<BDB> of course.
 
-=head1 AUTHOR
+=head1 AUTHOR/SUPPORT/CONTACT
 
- Marc Lehmann <schmorp@schmorp.de>
- http://home.schmorp.de/
+   Marc A. Lehmann <schmorp@schmorp.de>
+   http://software.schmorp.de/pkg/Coro.html
 
 =cut
 
