@@ -28,7 +28,7 @@ use base Exporter::;
 use Coro ();
 use Coro::AnyEvent ();
 
-our $VERSION = 6.42;
+our $VERSION = 6.49;
 our @EXPORT_OK = qw(timeout sleep);
 
 # compatibility with older programs
@@ -79,10 +79,10 @@ use overload 'bool' => \&bool, '0+' => \&bool;
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHOR/SUPPORT/CONTACT
 
- Marc Lehmann <schmorp@schmorp.de>
- http://home.schmorp.de/
+   Marc A. Lehmann <schmorp@schmorp.de>
+   http://software.schmorp.de/pkg/Coro.html
 
 =cut
 
